package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: May 31, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Responses struct {
Code int32 `json:"code"`
Status string `json:"status"`
Body string `json:"body"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.