package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: May 31, 2020
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Database struct {
Address string `json:"address" default:"127.0.0.1"`
Username string `json:"username" default:""`
Password string `json:"password" default:""`
BucketName string `json:"bucket_name" default:"metadata"`
}
type Error struct {
Code int `json:"code"`
Message string `json:"message"`
}
type Global struct {
Debug bool `json:"debug"`
AutoProvide bool `json:"auto_provide"`
}
type Logs struct {
Default string `json:"default"`
Error string `json:"error"`
}
type MetadataGeneralErrors struct {
MissingName Error `json:"missing_name"`
MissingFormat Error `json:"missing_format"`
MissingCreationTime Error `json:"missing_creation_time"`
InvalidModificationTime Error `json:"invalid_modification_time"`
}
type Server struct {
Port string `json:"port" default:"8080"`
Logs Logs `json:"logs"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.